/*************************************************************************
 *
 * Copyright (c) 2008-2011, Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * See the LICENSE.txt file shipped along with this file for the license.
 *
 *************************************************************************/
 
import QtQuick 1.0
 

Item {
    width: 360
    height: 640

    Image {
        id: background
        source: "images/background.jpg"
    }

    ListModelExample {
        id: listModel
    }

    Item {
        id: clippedItem
        width: 360
        height: 500
        anchors.top: background.top
        anchors.topMargin: 60
        anchors.left: background.left
        anchors.leftMargin: 20
        clip: true

        ListView {
            id: listExample
            anchors.fill: parent
            orientation: "Vertical"
            model: listModel
            delegate: itemComponent
            cacheBuffer: 100
        }
    }

    Component {
        id: itemComponent
        Item {
            width: 330
            height: 45
            Text {
                id: nameTxt
                font.family: "Univers LT Std"
                color: "#c8c8c8"
                font.pixelSize: 22
                text: model.name
                anchors.left: parent.left
                anchors.leftMargin: 50
                anchors.top: parent.top
                anchors.topMargin: 8
            }

            Image {
                id: deleteButton
                source: "images/delete.png"
                anchors.left: parent.left
                MouseArea{
                    anchors.fill: parent
                    onClicked: {
                        listModel.remove(index);
                    }
                }
            }

            Rectangle {
                id: divisionLine
                color: "#2c2e38"
                height: 1
                width: 330
                anchors.top: nameTxt.bottom
                anchors.topMargin: 10
            }
        }
    }

    Image {
        id: shadowDetail
        source: "images/shadow_detail.png"
        anchors.top: clippedItem.top
    }

    Image {
        id: textBg
        source: "images/textfield.png"
        anchors.top: clippedItem.bottom
        anchors.topMargin: 10
        anchors.left: clippedItem.left

        TextInput {
            id: inputText
            height: 30
            width: 275
            font.family: "Univers LT Std"
            color: "#c8c8c8"
            font.pixelSize: 20
            anchors.top: parent.top
            anchors.topMargin: 14
            anchors.left: parent.left
            anchors.leftMargin: 10
        }
    }

    Image {
        id: addButton
        source: "images/button_add.png"
        anchors.left: textBg.right
        anchors.leftMargin: 5
        anchors.top: textBg.top
        MouseArea{
            anchors.fill: parent
            onClicked: {
                if(inputText.text != "") {
                    listModel.insert(0, {"name": inputText.text});
                    inputText.text = "";
                }
            }
        }
    }

    Text {
        id: countText
        font.family: "Univers LT Std"
        color: "#c8c8c8"
        font.pixelSize: 20
        anchors.bottom: clippedItem.top
        anchors.right: clippedItem.right
        anchors.rightMargin: 50
        text: "List Lenght:" + listModel.count
    }

}
